#!/usr/bin/env python3

# This amulet test deploys the bundles.yaml file in this directory.

import os
import unittest
import yaml
import amulet
import sys
import requests
import time 

# Lots of prereqs on this charm (eg: java), so give it a large timeout
seconds_to_wait = 1000


class BundleTest(unittest.TestCase):
    """ Create a class for testing the charm in the unit test framework. """
    @classmethod
    def setUpClass(cls):
        """ Set up an amulet deployment using the bundle. """
        d = amulet.Deployment(juju_env='local', series='trusty')
    # We have a contextual test, if no config is present, initialze the
    # test with an empty configuration set
        config = {}
        local_path = os.path.join(os.path.dirname(__file__), 'local.yaml')
        with open(local_path, "r") as fd:
            config = yaml.safe_load(fd)

        host = config.get('wxs').get('wxs_host')
        print('Using HOST  %s' % host)
        # Test if a WXS host for the repository is defined
        if not host:
            print("You need to define a host for the IBMWXS packages"
                  " repository.\n Edit local.yaml or tests/00-setup"
                  " and run it again.")
            sys.exit(1)

        package_dir = config.get('wxs').get('wxs_package_dir')
        print('Using package_dir  %s' % package_dir)
        # Test if a WXS package_dir for the repository is defined
        if not package_dir:
            print("You need to define a package_dir for the IBMWXS packages"
                  " repository.\n Edit local.yaml or tests/00-setup"
                  " and run it again.")
            sys.exit(1)

        wxs_username = config.get('wxs').get('wxs_username')
        print('Using wxs_username  %s' % wxs_username)
        # Test if a WXS wxs_username for the repository is defined
        if not wxs_username:
            print("You need to define a wxs_username for the IBMWXS packages"
                  " repository.\n Edit local.yaml or tests/00-setup"
                  " and run it again.")
            sys.exit(1)

        wxs_password = config.get('wxs').get('wxs_password')
        print('Using wxs_password  %s' % wxs_password)
        # Test if a WXS  for the repository is defined
        if not wxs_password:
            print("You need to define a wxs_password for the IBMWXS packages"
                  " repository.\n Edit local.yaml or tests/00-setup"
                  " and run it again.")
            sys.exit(1)

        basepkg = config.get('wxs').get('wxs_base_package')
        print('Using IBMWXS base package %s' % basepkg)
        if not basepkg:
            print("You need to define a base package name for IBM WXS.\n"
                  " Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)

        fixpkg = config.get('wxs').get('wxs_fix_pkg')
        print('Using IBMWXS fix package %s' % fixpkg)
        if not fixpkg:
            print("You need to define a fix package name for IBM WXS.\n"
                  " Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)

        imname = config.get('wxs').get('im_name')
        print('Using IBMWXS IM package %s' % imname)
        if not imname:
            print("You need to define a IM package name for IBM WXS.\n"
                  " Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)
        sha_base_pkg = config.get('wxs').get('sha_base_pkg')
        print('Using IBMWXS sha base package %s' % sha_base_pkg)
        if not sha_base_pkg:
            print("You need to define a SHA Base package  for IBM WXS.\n"
                  " Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)
        sha_fix_pkg = config.get('wxs').get('sha_fix_pkg')
        print('Using IBMWXS sha fix package %s' % sha_fix_pkg)
        if not sha_fix_pkg:
            print("You need to define a SHA FIX package for IBM WXS.\n"
                  " Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)
        sha_im_pkg = config.get('wxs').get('sha_im_pkg')
        print('Using IBMWXS sha IM  package %s' % sha_im_pkg)
        if not sha_im_pkg:
            print("You need to define a SHA IM package  for IBM WXS.\n"
                  " Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)
        # Software doesn't actually install until you accept the license
        d.add('ibmwxs')
        d.configure('ibmwxs', { 'accept-ibm-wxs-license': True,
                               'accept-ibm-im-license': True,
                               'host': host,
                               'package_dir': package_dir,
                               'username': wxs_username,
                               'password': wxs_password,
                               'wxs_base_file_name': basepkg,
                               'wxs_fixpack_file_name': fixpkg,
                               'im_file_name': imname,
                               'sha_base': sha_base_pkg,
                               'sha_fixpack': sha_fix_pkg,
                               'sha_im': sha_im_pkg })

        d.setup(seconds_to_wait)
        d.sentry.wait(seconds_to_wait)
        cls.d = d

    def test_deployed(self):
        """ Test to see if the bundle deployed successfully. """
        self.assertTrue(self.d.deployed)
        ibmwxs_unit = self.d.sentry.unit['ibmwxs/0']
    # Checking the WXS
        cmd = "/opt/ibm/WXS/ObjectGrid/gettingstarted/runclient.sh g key1"
        ibmwxs_unit.run(cmd)

if __name__ == '__main__':
    unittest.main()
